@@ -21,6 +21,14 @@ Mojo::Cookie class in L<SPVM> an abstract base class for HTTP cookie containers,
     
   }
 
+=head1 Interfaces
+
+=over 2
+
+=item * L<Stringable|SPVM::Stringable>
+
+=back
+
 =head1 Fields
 
 =head2 name
@@ -65,7 +73,11 @@ Meant to be overloaded in a child class.
 
 =head1 See Also
 
-L<SPVM::Mojolicious>
+=over 2
+
+=item * L<SPVM::Mojolicious>
+
+=back
 
 =head1 Copyright & License
 
